/*
        GPK.H

        Description of GPK package format used by the application installer
        for the HP OmniGo 100 device.

        by Marcus Grber 1996, based on an analysis by Manfred Matzinger
*/


/* 1) File header: */

struct GPK_header {
  char ID[8];                           /* "GEOS_GPX" (format id) */
    #define ID_VALUE        "GEOS_GPX"
  long _x1;                             /* = 1 (probably format version) */
    #define x1_VALUE        1
  char device[4];                       /* "JEDI" (probably target device) */
    #define device_VALUE    "JEDI"
  long _x2;                             /* = 1 (device version?) */
    #define x2_VALUE        1

  unsigned short n_files;
  long pos_title;                       /* file offset of title */
  long pos_desc;                        /* file offset of description */
};

/*
     This is followed by as many longwords as specified by GPK_head.n_files,
     each of which points to the start of one fileblock (see below).

  2) At the offset of the title/description you will find text, terminated by
     NULL.

  3) At the offset of a fileblock you will find:

  filename, terminated by NULL
  complete path, terminated by NULL
  version string, terminated by NULL
  4 bytes for the size of the file

  If the size of the file is non-zero (zero length files being used for
  removing files created by the program), the size value is followed by
  another 4 byte value specifying the number of blocks containing the file
  data.

  Each block starts with a 4 byte value specifying the number of data bytes in
  the block (I always found this to be 1FF8h, except for the last block of a
  file which may be smaller), followed by as many data bytes as indicated by
  that number. The next block, if any, will follow immediately after that.
*/

#define DEFAULT_BLOCK_SIZE 0x1FF8
